@@ -10,12 +10,12 @@ from sys import stdout
 class NIHiCiteEntry:
     """Holds NIH iCite data for one PubMed ID (PMID)"""
 
-    fields = ['pmid', 'aart_type', 'aart_animal', 'nih_perc', 'nih_sd', 'year',
+    fields = ['pmid', 'aart_type', 'aart_animal', 'nih_perc', 'nih_group', 'year',
               'num_cites_all', 'clin', 'references',
               'A', 'author1', 'title']
 
     pat_pre = ('{pmid:8} {aart_type} {aart_animal} '
-               '{nih_perc:3} {nih_sd} {year} {num_cites_all:5} {clin:2} {references:3} '
+               '{nih_perc:3} {nih_group} {year} {num_cites_all:5} {clin:2} {references:3} '
               )
     pat_str = pat_pre + 'au[{A:02}]({author1}) {title}'
 
@@ -24,14 +24,16 @@ class NIHiCiteEntry:
               '{A:2}|{author1:16}|{title}'
              )
 
-    associated_pmids = {'cited_by_clin', 'cited_by', 'references'}
+    citekeys = {'cited_by_clin', 'cited_by'}
+    refkey = {'references',}
+    associated_pmid_keys = citekeys.union(refkey)
 
     hdr = pat_str.format(
         pmid='PMID',
-        year='YR',
+        year='YEAR',
         aart_type='RP',
         aart_animal='HAMCc',
-        nih_sd='SD',
+        nih_group='G',
         nih_perc='  %',
         num_cites_all='  cit',
         clin='cli',
@@ -44,7 +46,7 @@ class NIHiCiteEntry:
         self.pmid = icite_dct['pmid']
         self.dct = icite_dct
         nih_perc = icite_dct['nih_percentile']
-        self.dct['nih_sd'] = nih_group  # 0 - 5
+        self.dct['nih_group'] = nih_group  # 0 - 5
         # pylint: disable=line-too-long
         self.dct['num_auth'] = len(icite_dct['authors'])
         self.dct['num_clin'] = len(icite_dct['cited_by_clin'])
@@ -54,6 +56,12 @@ class NIHiCiteEntry:
         self.dct['nih_perc'] = round(nih_perc) if nih_perc is not None else 110 + num_cites_all
         self.dct['num_refs'] = len(icite_dct['references'])
 
+    ## TBD:
+    ## def __eq__(self, rhs):
+    ##     if self.pmid == rhs.pmid:
+    ##         return False
+    ##     return True
+
     def get_au1_lastname(self):
         """Get the last name of the first author"""
         aus = self.dct['authors']
@@ -89,7 +97,7 @@ class NIHiCiteEntry:
     @staticmethod
     def line_fmt():
         """Return the format of the paper line"""
-        return 'PubMedID RP HAMCc % SD YEAR x y z au[A](First Author) Title of paper'
+        return 'PubMedID RP HAMCc % G YEAR x y z au[A](First Author) Title of paper'
 
     @staticmethod
     def prt_key_desc(prt=stdout):
@@ -113,7 +121,7 @@ class NIHiCiteEntry:
         prt.write('     NIH section, based on Relative Citation Ratio (RCR):\n')
         prt.write('     ----------------------------------\n')
         prt.write('         %: NIH citation percentile rounded to an integer. -1 means "not determined" or TBD\n')
-        prt.write('        SD: NIH citation percentile group: 0=-3SD 1=-2SD 2=+/-1SD 3=+2SD 4=+3SD or i=TBD\n\n')
+        prt.write('         G: NIH citation percentile group: 0=-3SD 1=-2SD 2=+/-1SD 3=+2SD 4=+3SD or i=TBD\n\n')
         prt.write('     YEAR/citations/references section:\n')
         prt.write('     ----------------------------------\n')
         prt.write('      YEAR: The year the article was published\n')
@@ -133,14 +141,14 @@ class NIHiCiteEntry:
     def _str(self, pat):
         """Return one-line string describing NIH iCite entry"""
         dct = self.dct
-        nih_sd = dct['nih_sd']
+        nih_group = dct['nih_group']
         nih_perc = dct['nih_perc']
         return pat.format(
             pmid=self.pmid,
             year=dct['year'],
             aart_type=self.get_aart_type(),
             aart_animal=self.get_aart_translation(),
-            nih_sd=str(nih_sd) if nih_sd != 5 else 'i',
+            nih_group=str(nih_group) if nih_group != 5 else 'i',
             nih_perc=nih_perc if nih_perc <= 100 else ' -1',
             num_cites_all=dct['num_cites_all'],
             clin=dct['num_clin'],
@@ -150,14 +158,13 @@ class NIHiCiteEntry:
             title=dct['title'],
         )
 
-    def get_assc_pmids(self, keys=None):
+    def get_assc_pmids(self, keys):
         """Get PMIDs associated with the given NIH iCite data"""
         pmids = set()
-        if keys is None:
-            keys = self.associated_pmids
+        s_dct = self.dct
         for assc_key in keys:
-            if self.dct[assc_key]:
-                pmids.update(self.dct[assc_key])
+            if s_dct[assc_key]:
+                pmids.update(s_dct[assc_key])
         return pmids
 
     def get_aart_type(self):
