@@ -14,10 +14,10 @@ def sortby_cite(obj):
     """Sort lists of iCite items"""
     return [-1*obj.dct['citation_count'], -1*obj.dct['year']]
 
-def sortby_nih_sd(obj):
+def sortby_nih_group(obj):
     """Sort lists of iCite items"""
     dct = obj.dct
-    return [-1*dct['nih_sd'], -1*dct['year'], -1*dct['nih_perc'],
+    return [-1*dct['nih_group'], -1*dct['year'], -1*dct['nih_perc'],
             -1*dct['citation_count'] + -1*dct['num_clin'],
             -1*dct['num_refs'],
             -1*dct['pmid']]
@@ -28,7 +28,7 @@ class NIHiCitePaper:
     """Holds NIH iCite data for one PubMed ID (PMID)"""
 
     sortby_dct = {
-        'nih_sd': sortby_nih_sd,
+        'nih_group': sortby_nih_group,
         'cite': sortby_cite,
         'year': sortby_year,
     }
@@ -36,10 +36,12 @@ class NIHiCitePaper:
     def __init__(self, pmid, pmid2icite, header=None, pmid2note=None):
         self.pmid = pmid
         self.pmid2icite = pmid2icite
+        ## print('PPPPPPPP NIHiCitePaper({}, len(pmid2icite)={})'.format(pmid, len(pmid2icite)))
         self.hdr = header  # A header to print before a paper
         # A short pmid2note to print at end of cite line
         self.pmid2note = {} if pmid2note is None else pmid2note
         self.icite = pmid2icite.get(pmid)
+        # Sets of NIHiCiteEntrys
         self.cited_by = self._init_pmids('cited_by')
         self.cited_by_clin = self._init_pmids('cited_by_clin')
         self.references = self._init_pmids('references')
@@ -65,7 +67,7 @@ class NIHiCitePaper:
         prt.write('    CLI: A clinical paper that cited TOP\n')
         prt.write("    REF: A paper referenced in the TOP paper's bibliography\n")
 
-    def prt_summary(self, prt=stdout, rpt_refs=True, sortby_cites='nih_sd', sortby_refs='nih_sd'):
+    def prt_summary(self, prt=stdout, sortby_cites='nih_group', sortby_refs='nih_group'):
         """Print summary of paper"""
         if self.hdr:
             prt.write('NAME: {NAME}\n'.format(NAME=self.hdr))
@@ -81,7 +83,7 @@ class NIHiCitePaper:
                 M=self.icite.dct['citation_count']))
         self._prt_list(self.cited_by, 'CIT', prt, sortby_cites)
         # References
-        if rpt_refs and self.references:
+        if self.references:
             prt.write('{N} of {M} References downloaded:\n'.format(
                 N=len(self.references),
                 M=self.icite.dct['num_refs']))
@@ -122,5 +124,15 @@ class NIHiCitePaper:
         """Get the line containing data downloaded from NIH iCite for only the featured paper"""
         return self.str_line()
 
+    ## TBD:
+    ## def __eq__(self, rhs):
+    ##     if self.pmid != rhs.pmid:
+    ##         return False
+    ##     if self.cited_by != rhs.cited_by:
+    ##         print('LHS:', self.cited_by)
+    ##         print('RHS:', rhs.cited_by)
+    ##         return False
+    ##     return True
+
 
 # Copyright (C) 2019-present DV Klopfenstein. All rights reserved.
